pub enum EquivVerdict {
Equivalent,
Differ(Vec<bool>),
}Expand description
The verdict of a symmetry-reduced equivalence check.
Variants
Equivalent
F and S denote the same Boolean function (same models).
Differ(Vec<bool>)
They differ; the assignment satisfies exactly one of the two formulas (a distinguishing witness).