assignment_weight_inventory

Function assignment_weight_inventory 

pub fn assignment_weight_inventory(
    num_vars: usize,
    clauses: &[Vec<Lit>],
) -> Option<Vec<u128>>
The weight inventory of a formula’s variable symmetry: entry w is the number of essentially- distinct (modulo symmetry) {0,1} assignments to the variables with exactly w ones — the weighted Pólya refinement of SymmetryProfile::assignment_orbits (which is the sum). None when the group is too large to enumerate.